@@ -1,6 +1,6 @@
 package Audio::Analyzer;
 
-our $VERSION = '0.22_02';
+our $VERSION = '0.01';
 
 use strict;
 use warnings;
@@ -14,7 +14,6 @@ use constant DEFAULT_SAMPLE_RATE => 44100;
 use constant DEFAULT_CHANNELS => 2;
 use constant DEFAULT_BITS_PER_SAMPLE => 16;
 
-#value can be undef if fileless operation is being used
 use constant INPUT => 0;
 use constant FILE_NAME => 1;
 use constant DFT_SIZE => 2;
@@ -28,7 +27,6 @@ use constant FREQ_CACHE => 9;
 use constant SCALER => 10;
 use constant BYTES => 11;
 use constant EOF_FOUND => 12;
-use constant FILELESS_BUFFER => 13;
 
 sub new {
 	my ($class, %opts) = @_;
@@ -42,42 +40,23 @@ sub new {
 	return $self;
 }
 
-sub add_samples {
-    my ($self, @samples) = @_;
-    push(@{$self->[FILELESS_BUFFER]}, @samples);
-    return;
-}
-
-sub sample_buffer_size {
-    my ($self) = @_;
-    return scalar(@{$self->[FILELESS_BUFFER]});
-}
-
 sub next {
 	my ($self) = @_;
-	my @samples;
-	my $chunk;
-	
-	if (defined($self->[INPUT])) {
-        my $pcm = $self->read_pcm;
-        
-        if (! defined($pcm)) {
-            return undef;
-        }
-        
-        @samples = $self->convert_pcm($pcm);
-        
-	} else {
-	    @samples = $self->get_fileless_samples;
-	    return undef unless @samples;
+	my $pcm = $self->read_pcm;
+	my @mags;
+
+	if (! defined($pcm)) {
+		return undef;
 	}
 
-
+	my @samples = $self->convert_pcm($pcm);
 	my $channels = $self->split_channels(@samples);
 
-	$chunk = Audio::Analyzer::Chunk->new($self, $channels);
+	for(my $i = 0; $i < scalar(@$channels); $i++) {
+		$mags[$i] = $self->do_fft($channels->[$i]);
+	}
 
-	return $chunk;
+	return \@mags;
 }
 
 sub progress {
@@ -109,6 +88,25 @@ sub freqs {
 	return $self->[FREQ_CACHE];
 }
 
+sub combine {
+	my ($self, $channels) = @_;
+	my $num_channels = scalar(@$channels);
+	my $length = scalar(@{$channels->[0]});
+	my @new;
+
+	for(my $i = 0; $i < $length; $i++) {
+		my @row;
+
+		for(my $j = 0; $j < $num_channels; $j++) {
+			push(@row, $channels->[$j][$i]);	
+		}
+
+		$new[$i] = $self->rms(@row);
+	}
+
+	return \@new;
+}
+
 #private interface starts here
 
 sub init {
@@ -123,13 +121,9 @@ sub init {
 	my $scaler;
 	my $fps;
 
-    if (exists($opts{'file'})) {
-        if (! defined($file = $opts{'file'})) {
-            croak "if the file option is given it must have a value";
-        }
-    } elsif (! defined $opts{fileless}) {
-        croak "no file was specified and fileless operation is not configured";
-    }
+	if (! defined($file = $opts{'file'})) {
+		croak "file is a required option";
+	}
 
 	if (! defined($dft_size = $opts{'dft_size'})) {
 		$dft_size = DEFAULT_DFT_SIZE;
@@ -154,26 +148,20 @@ sub init {
 	$read_size = $dft_size * $channels * $bits_per_sample / 8;
 
 	if (defined($fps = $opts{'fps'})) {
-	    croak "unable to use audio/visual sync with fileless operation"
-	       unless defined $file; 
 		$seek_step = $sample_rate / $fps * $bits_per_sample / 8 * $channels;	
-	} elsif (defined $seek_step && ! defined $file) {
-        croak "unable to use seek_step with fileless operation";
 	} elsif (! defined($seek_step = $opts{'seek_step'})) {
 		$seek_step = $read_size;
 	}
 
-    if (defined($file)) {
-        if (ref($file) eq 'GLOB') {
-            $self->[INPUT] = $file;
-            $self->[FILE_NAME] = scalar($file); 
-        } else {
-            croak "could not open $file: $!" unless open(PCM, $file);
-            
-            $self->[INPUT] = \*PCM;
-            $self->[FILE_NAME] = $file;
-        }
-    }
+	if (ref($file) eq 'GLOB') {
+		$self->[INPUT] = $file;
+		$self->[FILE_NAME] = scalar($file);	
+	} else {
+		croak "could not open $file: $!" unless open(PCM, $file);
+		
+		$self->[INPUT] = \*PCM;
+		$self->[FILE_NAME] = $file;
+	}
 
 	$self->[BYTES_PER_SAMPLE] = $bits_per_sample / 8;
 	$self->[CHANNELS] = $channels;
@@ -183,10 +171,6 @@ sub init {
 	$self->[READ_SIZE] = $read_size;
 	$self->[BYTES] = 0;
 	$self->[EOF_FOUND] = 0;
-	
-	unless(defined($file)) {
-	    $self->[FILELESS_BUFFER] = [];
-	}
 
 	if (! exists($opts{scaler})) {
 		$scaler = Audio::Analyzer::ACurve->new($self);
@@ -201,6 +185,48 @@ sub init {
 	return $self;
 }
 
+sub rms {
+	my $self = shift(@_);
+	my $size = scalar(@_);
+	my $sum;
+
+	for(my $i = 0; $i < $size; $i++) {
+		$sum += $_[$i] ** 2;
+	}
+
+	$sum /= $size;
+
+	return sqrt($sum);
+}
+
+sub do_fft {
+	my ($self, $samples) = @_;
+	my $fft = Math::FFT->new($samples);
+	my $coeff = $fft->rdft;
+	my $size = scalar(@$coeff);
+	my $k = 0;
+	my @mag;
+
+	$mag[$k] = sqrt($coeff->[$k*2]**2);
+
+	for($k = 1; $k < $size / 2; $k++) {
+		$mag[$k] = sqrt(($coeff->[$k * 2] ** 2) + ($coeff->[$k * 2 + 1] ** 2));
+	}
+
+	$self->scale(\@mag);
+
+	return \@mag;
+}
+
+sub scale {
+	my ($self, $mags) = @_;
+	my $scaler = $self->[SCALER];
+	
+	if (defined($scaler)) {
+		$scaler->scale($mags);
+	}
+}
+
 sub split_channels {
 	my ($self, @samples) = @_;
 	my $channels = $self->[CHANNELS];
@@ -215,7 +241,6 @@ sub split_channels {
 	return \@split;
 }
 
-
 #converts PCM into floating point representation
 sub convert_pcm {
 	my ($self, $pcm) = @_;
@@ -224,7 +249,7 @@ sub convert_pcm {
 
 	if ($bytes_per_sample == 2) {
 		while(length($pcm) >= 2) {
-			my $sample = unpack('s<', substr($pcm, 0, 2, ''));
+			my $sample = unpack('s', substr($pcm, 0, 2, ''));
 			push(@samples, $sample);
 		}
 	} else {
@@ -234,21 +259,6 @@ sub convert_pcm {
 	return @samples;
 }
 
-sub get_fileless_samples {
-    my ($self) = @_;
-    my $input = $self->[INPUT];
-    my $read_size = $self->[READ_SIZE];
-    my $fileless_buffer = $self->[FILELESS_BUFFER];
-    my $samples_needed = $read_size / $self->[BYTES_PER_SAMPLE];
-    
-    if (defined $input) {
-        die "read_buffer() was called for fileless operation but there was an input file ref?";
-    }
-
-    return () unless scalar(@$fileless_buffer) >= $samples_needed;
-    return splice(@$fileless_buffer, 0, $samples_needed);
-}
-
 sub read_pcm {
 	my ($self) = @_;
 	my $input = $self->[INPUT];
@@ -259,9 +269,7 @@ sub read_pcm {
 	my $buf;
 	my $ret;
 	my $rewind;
-	
-	die "there was no input filehandle ref" unless defined $input;
-	
+
 	$ret = read($input, $buf, $read_size);
 
 	if (! defined($ret)) {
@@ -294,121 +302,9 @@ sub read_pcm {
 	return $buf;
 }
 
-sub scaler {
-	my ($self) = @_;
-	
-	return $self->[SCALER];
-}
-
-package Audio::Analyzer::Chunk;
-
-our $VERSION = '0.02';
-
-use strict;
-use warnings;
-
-sub new {
-	my ($class, $analyzer, $channels) = @_;
-	my $self = {};
-
-	$self->{analyzer} = $analyzer;
-	$self->{channels} = $channels;
-
-	bless($self, $class);
-
-	return $self;
-}
-
-sub pcm {
-	my ($self) = @_;
-
-	return $self->{channels};
-}
-
-sub fft {
-	my ($self) = @_;
-	my $channels = $self->{channels};
-	my @mags;
-
-	for(my $i = 0; $i < scalar(@$channels); $i++) {
-		$mags[$i] = $self->do_fft($channels->[$i]);
-	}
-
-	return \@mags;
-}
-
-sub rms {
-	my $self = shift(@_);
-	my $size = scalar(@_);
-	my $sum;
-
-	for(my $i = 0; $i < $size; $i++) {
-		$sum += $_[$i] ** 2;
-	}
-
-	$sum /= $size;
-
-	return sqrt($sum);
-}
-
-sub combine_fft {
-	my ($self, $channels) = @_;
-	my $num_channels = scalar(@$channels);
-	my $length = scalar(@{$channels->[0]});
-	my @new;
-
-	for(my $i = 0; $i < $length; $i++) {
-		my @row;
-
-		for(my $j = 0; $j < $num_channels; $j++) {
-			push(@row, $channels->[$j][$i]);	
-		}
-
-		$new[$i] = $self->rms(@row);
-	}
-
-	return \@new;
-}
-
-sub analyzer {
-	my ($self) = @_;
-
-	return $self->{analyzer};
-}
-
-#private methods
-
-sub do_fft {
-	my ($self, $samples) = @_;
-	my $fft = Math::FFT->new($samples);
-	my $coeff = $fft->rdft;
-	my $size = scalar(@$coeff);
-	my $k = 0;
-	my @mag;
-
-	$mag[$k] = sqrt($coeff->[$k*2]**2);
-
-	for($k = 1; $k < $size / 2; $k++) {
-		$mag[$k] = sqrt(($coeff->[$k * 2] ** 2) + ($coeff->[$k * 2 + 1] ** 2));
-	}
-
-	$self->scale(\@mag);
-
-	return \@mag;
-}
-
-sub scale {
-	my ($self, $mags) = @_;
-	my $scaler = $self->analyzer->scaler;
-	
-	if (defined($scaler)) {
-		$scaler->scale($mags);
-	}
-}
-
 package Audio::Analyzer::ACurve;
 
-our $VERSION = '0.02';
+our $VERSION = '0.01';
 
 use strict;
 use warnings;
@@ -482,7 +378,7 @@ sub scale {
 
 package Audio::Analyzer::AutoScaler;
 
-our $VERSION = '0.02';
+our $VERSION = '0.01';
 
 use strict;
 use warnings;
@@ -521,7 +417,7 @@ __END__
 
 =head1 NAME
 
-Audio::Analyzer - Makes using Math::FFT very easy for audio analysis 
+Audio::Analyzer
 
 =head1 SYNOPSIS
 
@@ -532,7 +428,7 @@ Audio::Analyzer - Makes using Math::FFT very easy for audio analysis
 
   $analyzer = Audio::Analyzer->new(file => $source);
 
-  while(defined($chunk = $analyzer->next)) {
+  while(defined($readings = $analyzer->next)) {
     my $done = $analyzer->progress;
 
     print "$done% completed\n";
@@ -543,9 +439,13 @@ Audio::Analyzer - Makes using Math::FFT very easy for audio analysis
   
 =head1 DESCRIPTION
 
-This module makes it easy to analyze audio files with the Fast Fourier 
+This module makes it easy to analyze music files with the Fast Fourier 
 Transform and sync the output of the FFT in time for visual representation.
 
+=head1 PLUG
+
+See http://musicwatcher.sf.net/ for programs that use this module.
+
 =head1 REFERENCE
 
 =over 4
@@ -560,9 +460,7 @@ by %opts. The options available are:
 =item file
 
 A required option; must be either a string which is a filename or a reference
-to an already open filehandle. The format must be little endian linear coded
-PCM using signed integers; this is the same format as a WAV file with the
-header ripped off. 
+to an already open filehandle.
 
 =item dft_size
 
@@ -616,45 +514,28 @@ between 0 and 1, with 1 being a magnitude of the peak level.
 
 =back
 
-=item $chunk = $analyzer->next;
+=item $channels = $analyzer->next;
 
-Iterate once and return a new chunk; see below for information on 
-Audio::Analyzer::Chunk.
+Iterate once and return the output of the Fourier Transform after scaling. An
+array ref is returned which has each channel's worth of information in it, as
+another array ref; the values of the second ref are the magnitude of each 
+frequency. 
+
+=item $combined = $analyzer->combine($channels);
+
+Combine together 2 or more channels of readings into a single array ref. The
+returned ref contains the RMS of each of the channel specific readings.
 
 =item $freqs = $analyzer->freqs;
 
 Return an array reference of the frequency numbers that we analyze. This array
-ref is the same size as the number of elements in each channel from $chunk->fft.
-
+ref is the same size as the output of $analyzer->next and serves to enumerate
+each position of that array.
 
 =item $completed = $analyzer->progress;
 
-Return a number between 0 and 99 that represents in percent how far along in 
-the file we have processed.
-
-=back
-
-=head1 CHUNK SYSTEM
-
-Instances of Audio::Analyzer::Chunk represent a set of PCM from the file. 
-Operations on instances of this class perform the FFT and access the PCM.
-
-=over 4
-
-=item $channels = $chunk->pcm;
-
-Return an array ref of channels; each array value is an array ref which contains
-the samples from the PCM converted to numbers between -1 and 1.
-
-=item $channels = $chunk->fft;
-
-Return an array ref of channels; each array value is an array ref which contains
-the magnitudes from the Fast Fourier Transform. Numbers are between 0 and 1.
-
-=item $combined = $chunk->combine_fft($channels);
-
-Combine together 2 or more channels of FFT output into a single array ref. The
-returned ref contains the RMS of each of the channel specific readings.
+Return a number between 0 and 99 that represents in percent how far along in the file
+we have processed.
 
 =back
 
@@ -671,31 +552,6 @@ inside the array reference and does not return any value.
 
 Your scaler class should also force all output to be between 0 and 1.
 
-=head1 EXAMPLE MEDIA
-
-The following pieces of media were done using Audio::Analyzer:
-
-=over 4 
-
-=item http://www.youtube.com/watch?v=W8Jk8rTP5lg
-
-=item http://www.youtube.com/watch?v=6yTEUBgvxs4
-
-Templatized PovRay scenes written out one file per frame then rendered
-into images individually with a make file.
-
-=item http://www.youtube.com/watch?v=bFp2zZlFgv4
-
-Imager::Graph generated pngs of the output of Audio::Analyzer and the internal
-state of a software beat detector.
-
-=back
-
-=head1 LIMITATIONS
-
-In no way shape or form should this module be considered accurate or
-correct enough for actual scientific analysis.
-
 =head1 AUTHOR
 
 This module was created and documented by Tyler Riddle E<lt>triddle@gmail.comE<gt>. 
@@ -712,13 +568,7 @@ your bug as I make changes.
 
 =head2 Known Bugs
 
-=over 4
-
-=item This module is still not passing tests on all types of hardware. See
-http://cpantesters.org/distro/A/Audio-Analyzer.html for details on what is
-and is not passing. 
-
-=back
+No known bugs at this time. 
 
 Copyright 2007 Tyler Riddle, all rights reserved.
 
